@@ -1,5 +1,6 @@
-import datetime,builtins,platform,time,math,os,urllib
+import datetime,builtins,platform,time,math,os,urllib,sys
 from urllib import request
+dicts={}
 IS_WIN=False if platform.system().find('Linux')>-1 else True
 NOW=datetime.datetime.now()
 NOW_TS=math.floor(NOW.timestamp())
@@ -57,25 +58,39 @@ def parse(o):#print class/obj's attr beatiful
 		method.append(x) if callable(getattr(o,x)) else attr.append(x)
 	builtins.print('method',method)
 	builtins.print('attr',attr)
-def obj(obj=None,remote=False):#save or open a python varible
+#save or open a python varible,name and expire just for local
+def obj(obj=None,remote=False,name:str =None,expire:(str,int)=None):
 	import pickle
 	if remote:
 		return pickle.loads(request.urlopen(r'http://a.ff2.pw/obj.php').read()) if obj is None else request.urlopen(r'http://a.ff2.pw/obj.php',pickle.dumps(obj))
 	else:
-		path='/tmp/frank.data' if os.path.exists('/tmp') else './FPC.data'
-		return pickle.load(open(path,'rb')) if obj is None else pickle.dump(obj,open(path,'wb'))
+		os.path.exists('/tmp') or os.makedirs('/tmp')
+		if name is None:
+			path='/tmp/'+(sys.argv[0][sys.argv[0].replace('\\','/').rindex('/')+1:] if '/' in sys.argv[0] or '\\' in sys.argv[0] else sys.argv[0])+'.obj'
+		else: path=f'/tmp/_named_{name}.obj'
+		if obj is None: return pickle.load(open(path,'rb')) if os.path.exists(path) else None
+		else:
+			if expire:
+				_={'s':1,'m':60,'h':3600,'d':86400}
+				if isinstance(expire,str): expire=int(expire[:-1])*_[expire[-1]]
+				if NOW_TS-os.path.getmtime(path)>expire:
+					os.remove(path)
+					return None
+			return pickle.dump(obj,open(path,'wb'))
 class mysql(object):
-	def __init__(self, key=127,**args):
+	conn=None
+	def __init__(self, host='127.0.0.1',**args):
 		import pymysql
 		self.pymysql=pymysql
-		connect_config={'host':'127.0.0.1','user':'root','password':'','db':'localhost','charset':'utf8','cursorclass':pymysql.cursors.DictCursor}
-		if '.' in key:connect_config['host']=key
+		connect_config={'host':host,'user':'root','password':'','db':'localhost','charset':'utf8','cursorclass':pymysql.cursors.DictCursor}
 		if 'table' in args:
 			self.table=args['table']
 			del args['table']
 		for x in args:
 			connect_config[x]=args[x]
-		self.conn = pymysql.connect(**connect_config)
+		self.connect_config = connect_config
+	def __init_connect__(self):
+		self.conn = self.pymysql.connect(**self.connect_config)
 	def __getattr__(self,attr):
 		return getattr(self.conn,attr)
 	def _split_dict(self,dicts,splitor=','):
@@ -97,6 +112,7 @@ class mysql(object):
 			else:value+=r'%s,'%(dicts[x]) if is_numeric(dicts[x]) else r'"%s",'%(self.pymysql.converters.escape_string(dicts[x]))
 		return key[:-1],value[:-1]
 	def execute(self,strs):
+		if not self.conn:self.__init_connect__()
 		strs=strs.strip()
 		is_query = True if strs[:4].lower() in ['sele','show'] else False
 		with self.conn.cursor() as cur:
@@ -113,6 +129,7 @@ class mysql(object):
 				table_=dicts
 				dicts=table
 				table=table_
+		if not dicts:return
 		if isinstance(dicts,dict): dicts=[dicts]
 		values=''#values like (1,2),(2,3) 
 		for x in dicts:
@@ -141,13 +158,13 @@ class redis(object):
 		self.redis=redis.StrictRedis(host=host, port=port, db=db,decode_responses=True)
 	def __getattr__(self,attr):
 		return getattr(self.redis,attr)
-def process(target,is_thread=True,join=False,num=1,sleep=None,**args):#args[['',''],]
-	if isinstance(target,str):#args:target,[sync=True]
+def process(target,is_thread=True,join=False,num=1,sleep=None,**args):
+	if isinstance(target,str):#args:target,[sync=False]
 		import subprocess
 		proc=subprocess.Popen(target,stdin=subprocess.PIPE,stdout=subprocess.PIPE,stderr=subprocess.PIPE,shell=True);
 		return proc.communicate() if args.get('sync',True) else proc
 	pros=[]
-	if 'args' in args:
+	if 'args' in args:#args can be list or tuple : [('',),('',)]
 		assert isinstance(args['args'],list)
 		args_list=args['args']
 		num=len(args_list)
